@@ -9,7 +9,10 @@ def extract_message(text):
     pattern = r'\[C:START\](.*?)\[C:END\]'
     matcher = re.search(pattern, text, re.DOTALL)
     if matcher:
-        return matcher.group(1)
+        raw_message = matcher.group(1).strip()
+        # Remove any extraneous text around the JSON content
+        cleaned_message = re.sub(r'^[^{]*|[^}]*$', '', raw_message)
+        return cleaned_message
     return None
 
 def review(openai_key, assistant_id, token, repo, message, gh_before, sha, author, webhook, websecret):
@@ -81,4 +84,6 @@ def main():
     review(args.openai_key, args.assistant_id, args.token, args.repo, args.message, args.gh_before, args.sha, args.author, args.webhook, args.websecret)
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
+    # print(extract_message("This is a test [C:START] ```json{\"message\": \"This is a test ```json {}```\"}``` [C:END] This is a test"))
+    # print(extract_message("This is a test [C:START] {\"message\": \"This is a test ```json {}```\"} [C:END] This is a test"))
\ No newline at end of file
